'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

/**
 *  useDidUpdate hook
 *
 *  Fires a callback on component update
 *  Can take in a list of conditions to fire callback when one of the
 *  conditions changes
 *
 * @param {function} callback The callback to be called on update
 * @param {Array} conditions The list of variables which trigger update when they are changed
 * @return {undefined}
 */
function useDidUpdate(callback, conditions) {
    const hasMountedRef = React.useRef(false);
    if (typeof conditions !== "undefined" && !Array.isArray(conditions)) {
        conditions = [conditions];
    }
    else if (Array.isArray(conditions) && conditions.length === 0) {
        console.warn("Using [] as the second argument makes useDidUpdate a noop. The second argument should either be `undefined` or an array of length greater than 0.");
    }
    React.useEffect(() => {
        if (hasMountedRef.current) {
            callback();
        }
        else {
            hasMountedRef.current = true;
        }
    }, conditions);
}

var intialState = { translations: {}, lang: 'es' };
// eslint-disable-next-line @typescript-eslint/no-explicit-any
var LangContext = React.createContext([intialState, function () { }]);
var useLangContext = function () { return React.useContext(LangContext); };
var LangProvider = function (props) {
    var children = props.children, lang = props.lang, onLang = props.onLang, translations = props.translations;
    var _a = React.useState({ lang: lang, translations: translations }), state = _a[0], setState = _a[1];
    useDidUpdate(function () {
        if (onLang) {
            onLang(state.lang);
        }
    }, [state.lang]);
    return React__default['default'].createElement(LangContext.Provider, { value: [state, setState] }, children);
};

var useLang = function () {
    var _a = useLangContext(), state = _a[0], setState = _a[1];
    var lang = state.lang, translations = state.translations;
    var setLang = function (props) {
        var finalLang;
        if (typeof props === 'function')
            finalLang = props(lang);
        else
            finalLang = props;
        return setState(function (acc) { return (__assign(__assign({}, acc), { lang: finalLang })); });
    };
    var t = translations[lang];
    if (!t) {
        throw Error('No lang configurated');
    }
    return { lang: lang, translations: translations, setLang: setLang, t: t };
};

var createLangCtx = function () {
    return { LangProvider: LangProvider, useLang: useLang };
};

var searchForTag = function (str, elements, element) {
    var finalElements = elements || [];
    var indexAttr = str.indexOf('<');
    var indexAttrFinal = str.indexOf('>');
    var firstSub = str.substring(0, indexAttr);
    if (!firstSub.includes('<') && indexAttr > 0) {
        finalElements.push(React__default['default'].createElement("span", { key: firstSub }, firstSub));
        str = str.substring(indexAttr, str.length);
        if (str) {
            return searchForTag(str, finalElements);
        }
    }
    if (indexAttr === 0) {
        var tag = str.substring(indexAttr + 1, indexAttrFinal);
        var isA = tag.includes('a');
        var href = '';
        var finalTag = "</" + tag + ">";
        var indexOfFinal = str.indexOf(isA ? '</a>' : "</" + tag + ">");
        var innerText = str.substring(indexAttrFinal + 1, indexOfFinal);
        if (isA) {
            var link = (str.match(/href="(.*?)"/g) || [])[0];
            href = link.replace('href=', '').replaceAll('"', '').replaceAll("'", '');
        }
        var hasInnerTag = innerText.includes('<');
        var finalElemet = React__default['default'].createElement(isA ? 'a' : tag, {
            children: innerText,
            key: innerText,
            href: href,
            target: isA ? '_blank' : undefined,
        });
        if (hasInnerTag) {
            finalElements.push(finalElemet);
            searchForTag(innerText, finalElements, finalElemet);
        }
        if (!element && !hasInnerTag) {
            finalElements.push(finalElemet);
        }
        if (element && !hasInnerTag) {
            var indexOfAct = finalElements.indexOf(element);
            finalElements[indexOfAct] = React__default['default'].cloneElement(element, { children: finalElemet });
        }
        str = str.substring(indexOfFinal + finalTag.length, str.length);
        if (str) {
            return searchForTag(str, finalElements);
        }
    }
    else {
        finalElements.push(React__default['default'].createElement("span", { key: str }, str));
        return finalElements;
    }
    return finalElements;
};
var AttrString = function (str) {
    var hasP = str.includes('<p>');
    if (!hasP)
        return searchForTag(str, []);
    return str
        .replace(/<\/p>/gi, '')
        .split('<p>')
        .filter(function (e) { return e; })
        .map(function (para) {
        return React__default['default'].createElement('p', { children: searchForTag(para, []) });
    });
};

exports.AttrString = AttrString;
exports.createLangCtx = createLangCtx;
//# sourceMappingURL=index.js.map
